Output and render functions for using singleQuestion within Shiny applications and interactive Rmd documents.
Usage
singleQuestionOutput(outputId, width = "100%", height = "400px")
renderSingleQuestion(expr, env = parent.frame(), quoted = FALSE)Arguments
- outputId
output variable to read from
- width, height
Must be a valid CSS unit (like
'100%','400px','auto') or a number, which will be coerced to a string and have'px'appended.- expr
An expression that generates a singleQuestion.
- env
The environment in which to evaluate
expr.- quoted
Is
expra quoted expression (withquote())? This is useful if you want to save an expression in a variable.
Value
singleQuestionOutput returns an HTML output element for use
in a Shiny UI definition. renderSingleQuestion returns a
server-side rendering function to be assigned to an output slot.
Examples
if (interactive()) {
library(shiny)
ui <- fluidPage(
singleQuestionOutput("quiz1")
)
server <- function(input, output) {
output$quiz1 <- renderSingleQuestion({
singleQuestion(
x = list(
question = "What is 2+2?",
options = c("3", "4", "5"),
answer = 2
),
title = "Quick Quiz"
)
})
}
shinyApp(ui, server)
}